@@ -71,6 +71,8 @@ struct _GeditViewFramePrivate
 
 	GtkWidget   *slider;
 	GtkWidget   *search_entry;
+	GtkWidget   *go_up_button;
+	GtkWidget   *go_down_button;
 
 	guint        typeselect_flush_timeout;
 	glong        view_scroll_event_id;
@@ -81,11 +83,6 @@ struct _GeditViewFramePrivate
 	guint        wrap_around : 1;
 };
 
-struct _GeditViewFrameClassPrivate
-{
-	GtkCssProvider *search_css;
-};
-
 enum
 {
 	PROP_0,
@@ -99,8 +96,7 @@ typedef enum
 	GEDIT_SEARCH_ENTRY_NOT_FOUND
 } GeditSearchEntryBgColor;
 
-G_DEFINE_TYPE_WITH_CODE (GeditViewFrame, gedit_view_frame, GTK_TYPE_BOX,
-                         g_type_add_class_private (g_define_type_id, sizeof (GeditViewFrameClassPrivate)))
+G_DEFINE_TYPE (GeditViewFrame, gedit_view_frame, GTK_TYPE_BOX)
 
 static void
 gedit_view_frame_finalize (GObject *object)
@@ -230,14 +226,11 @@ set_entry_background (GeditViewFrame          *frame,
 
 	if (col == GEDIT_SEARCH_ENTRY_NOT_FOUND)
 	{
-		gtk_style_context_add_provider (context,
-		                                GTK_STYLE_PROVIDER (GEDIT_VIEW_FRAME_GET_CLASS (frame)->priv->search_css),
-		                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+		gtk_style_context_add_class (context, "not-found");
 	}
-	else /* reset */
+	else
 	{
-		gtk_style_context_remove_provider (context,
-		                                   GTK_STYLE_PROVIDER (GEDIT_VIEW_FRAME_GET_CLASS (frame)->priv->search_css));
+		gtk_style_context_remove_class (context, "not-found");
 	}
 }
 
@@ -625,7 +618,7 @@ search_entry_populate_popup (GtkEntry       *entry,
 		return;
 
 	/* separator */
-	menu_item = gtk_menu_item_new ();
+	menu_item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
 
@@ -772,6 +765,9 @@ customize_for_search_mode (GeditViewFrame *frame)
 
 		gtk_widget_set_tooltip_text (frame->priv->search_entry,
 		                             _("String you want to search for"));
+
+		gtk_widget_show (frame->priv->go_up_button);
+		gtk_widget_show (frame->priv->go_down_button);
 	}
 	else
 	{
@@ -779,6 +775,9 @@ customize_for_search_mode (GeditViewFrame *frame)
 
 		gtk_widget_set_tooltip_text (frame->priv->search_entry,
 		                             _("Line you want to move the cursor to"));
+
+		gtk_widget_hide (frame->priv->go_up_button);
+		gtk_widget_hide (frame->priv->go_down_button);
 	}
 
 	gtk_entry_set_icon_from_gicon (GTK_ENTRY (frame->priv->search_entry),
@@ -908,16 +907,15 @@ search_entry_focus_out_event (GtkWidget      *widget,
 }
 
 static GtkWidget *
-create_button_from_stock (const gchar *stock_id)
+create_button_from_symbolic (const gchar *icon_name)
 {
 	GtkWidget *button;
 
 	button = gtk_button_new ();
 	gtk_widget_set_can_focus (button, FALSE);
-	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
 	gtk_button_set_image (GTK_BUTTON (button),
-			      gtk_image_new_from_stock (stock_id,
-							GTK_ICON_SIZE_MENU));
+	                      gtk_image_new_from_icon_name (icon_name,
+	                                                    GTK_ICON_SIZE_MENU));
 
 	return button;
 }
@@ -939,10 +937,14 @@ on_go_down_button_clicked (GtkWidget      *button,
 static GtkWidget *
 create_search_widget (GeditViewFrame *frame)
 {
-	GtkWidget          *search_widget;
-	GtkWidget          *button;
+	GtkWidget *search_widget;
+	GtkStyleContext *context;
+
+	search_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+
+	context = gtk_widget_get_style_context (search_widget);
+	gtk_style_context_add_class (context, GTK_STYLE_CLASS_LINKED);
 
-	search_widget = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
 	gtk_widget_show (search_widget);
 
 	g_signal_connect (search_widget, "key-press-event",
@@ -982,25 +984,19 @@ create_search_widget (GeditViewFrame *frame)
 	gtk_container_add (GTK_CONTAINER (search_widget),
 	                   frame->priv->search_entry);
 
-	customize_for_search_mode (frame);
-
 	/* Up/Down buttons */
-	button = create_button_from_stock (GTK_STOCK_GO_UP);
-	gtk_widget_show (button);
-
-	gtk_box_pack_start (GTK_BOX (search_widget), button, FALSE, FALSE, 0);
-
-	g_signal_connect (button,
+	frame->priv->go_up_button = create_button_from_symbolic ("go-up-symbolic");
+	gtk_box_pack_start (GTK_BOX (search_widget), frame->priv->go_up_button,
+	                    FALSE, FALSE, 0);
+	g_signal_connect (frame->priv->go_up_button,
 	                  "clicked",
 	                  G_CALLBACK (on_go_up_button_clicked),
 	                  frame);
 
-	button = create_button_from_stock (GTK_STOCK_GO_DOWN);
-	gtk_widget_show (button);
-
-	gtk_box_pack_start (GTK_BOX (search_widget), button, FALSE, FALSE, 0);
-
-	g_signal_connect (button,
+	frame->priv->go_down_button = create_button_from_symbolic ("go-down-symbolic");
+	gtk_box_pack_start (GTK_BOX (search_widget), frame->priv->go_down_button,
+	                    FALSE, FALSE, 0);
+	g_signal_connect (frame->priv->go_down_button,
 	                  "clicked",
 	                  G_CALLBACK (on_go_down_button_clicked),
 	                  frame);
@@ -1210,9 +1206,6 @@ static void
 gedit_view_frame_class_init (GeditViewFrameClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	static const gchar error_style[] =
-		"@define-color text_color @error_fg_color;\n"
-		"@define-color base_color @error_bg_color;\n";
 
 	object_class->finalize = gedit_view_frame_finalize;
 	object_class->dispose = gedit_view_frame_dispose;
@@ -1235,11 +1228,6 @@ gedit_view_frame_class_init (GeditViewFrameClass *klass)
 	                                                      G_PARAM_STATIC_STRINGS));
 
 	g_type_class_add_private (object_class, sizeof (GeditViewFramePrivate));
-
-	klass->priv = G_TYPE_CLASS_GET_PRIVATE (klass, GEDIT_TYPE_VIEW_FRAME, GeditViewFrameClassPrivate);
-
-	klass->priv->search_css = gtk_css_provider_new ();
-	gtk_css_provider_load_from_data (klass->priv->search_css, error_style, -1, NULL);
 }
 
 static GMountOperation *
@@ -1299,6 +1287,7 @@ gedit_view_frame_init (GeditViewFrame *frame)
 
 	/* Add slider */
 	frame->priv->slider = gedit_floating_slider_new ();
+	gtk_widget_set_name (frame->priv->slider, "search-slider");
 	gtk_widget_set_halign (frame->priv->slider, GTK_ALIGN_END);
 	gtk_widget_set_valign (frame->priv->slider, GTK_ALIGN_START);
 
